require 'spec_helper'

describe Jafry::Builder do
  before(:each) do
    write_file('test.json', %Q({"name":"test"}))
  end

  after(:each) do
    Jafry::Identificator.schemes.clear
    delete_file('test.json')
  end

  let(:stub_obj) { Class.new { include Jafry::Builder }.new }

  it '#build' do
    expect(stub_obj.build('test')).to eq({"id" => 1, "name" => "test"})
  end

  it 'builds scheme with options' do
    expect(stub_obj.build('test', {name: "foo", wrap: "data"})).to eq({"data" => {"id" => 1, "name" => "foo"}})
  end

  it '#create' do
    expect(stub_obj.create('test')).to eq("{\"name\":\"test\",\"id\":1}")
  end

  it '#build_list' do
    expect(stub_obj.build_list('test', 2)).to eq([{"id" => 1, "name" => "test"}, {"id" => 2, "name" => "test"}])
  end

  it '#create_list' do
    expect(stub_obj.create_list('test', 2)).to eq("[{\"name\":\"test\",\"id\":1},{\"name\":\"test\",\"id\":2}]")
  end

  context "from unexisting file" do
    it {expect { stub_obj.build('foo') }.to output(/Please, create correct scheme file first/).to_stdout}
  end
end