require 'spec_helper'

describe Jafry::Identificator do
  let(:scheme) {Jafry::Scheme.new({name: "test"})}

  context "with unregistered scheme" do
    it {expect(described_class.schemes).to be_empty}
  end

  context "with registered scheme" do
    before(:each) do
      scheme.self_name = 'test'
      Jafry::Configurator.set_config('test')
      described_class.register_scheme('foo')
    end

    it '.register_scheme' do
      expect(described_class.schemes.last).to eq({scheme: 'foo', counter: 0})
    end

    it ".find_scheme" do
      expect(described_class.find_scheme('foo')).to eq({scheme: 'foo', counter: 0})
    end

    it ".find_scheme_or_register" do
      expect(described_class.find_or_register('foo')).to eq({scheme: 'foo', counter: 0})
      Jafry::Configurator.set_config('bar')
      described_class.find_or_register('bar')
      expect(described_class.schemes).to include({scheme: 'bar', counter: 0})
    end

    it ".set_id_for_scheme" do

      described_class.set_id_for_scheme(scheme)
      expect(scheme.id).to eq(1)
    end

    context "sets with another id_wrapper" do
      before do
        scheme.self_name = 'test'
        Jafry::Configurator.set_config('test', {id_wrapper: 'foo_id'})
        described_class.set_id_for_scheme(scheme)
      end

      it {expect(scheme).to respond_to(:foo_id)}
    end

    context "sets with another id_type" do
      before do
        scheme.self_name = 'test'
        Jafry::Configurator.set_config('test', {id_type: 'hash'})
        described_class.set_id_for_scheme(scheme)
      end

      it {expect(scheme.id.size).to eq(32)}
    end
  end
end